chromium
========

.. automodule:: deltona.chromium
   :members:
   :show-inheritance:

.. _Bug 40595456 - PWA icons can be lost (on sync?) and reverted to a letter: https://issues.chromium.org/issues/40595456
